import { lowerCamelCase } from "@protobuf-ts/runtime";
/**
 * The available client styles from @protobuf-ts/plugin
 * The extensions are declared in protobuf-ts.proto
 */
export var ClientStyle;
(function (ClientStyle) {
    /**
     * Do not emit a client for this service.
     */
    ClientStyle[ClientStyle["NONE"] = 0] = "NONE";
    /**
     * Use the call implementations of @protobuf-ts/runtime-rpc.
     * This is the default behaviour.
     */
    ClientStyle[ClientStyle["CALL"] = 1] = "CALL";
    /**
     * Use promises as return type.
     * This style can only be used for unary methods (no server or client
     * streaming).
     */
    ClientStyle[ClientStyle["PROMISE"] = 2] = "PROMISE";
    /**
     * Use Observables from the "rxjs" package for requests and responses.
     */
    ClientStyle[ClientStyle["RX"] = 3] = "RX";
})(ClientStyle || (ClientStyle = {}));
/**
 * Turns PartialMethodInfo into MethodInfo.
 */
export function normalizeMethodInfo(method, service) {
    var _a, _b, _c;
    let m = method;
    m.service = service;
    m.localName = (_a = m.localName) !== null && _a !== void 0 ? _a : lowerCamelCase(m.name);
    // noinspection PointlessBooleanExpressionJS
    m.serverStreaming = !!m.serverStreaming;
    // noinspection PointlessBooleanExpressionJS
    m.clientStreaming = !!m.clientStreaming;
    m.options = (_b = m.options) !== null && _b !== void 0 ? _b : {};
    m.idempotency = (_c = m.idempotency) !== null && _c !== void 0 ? _c : undefined;
    return m;
}
/**
 * Read custom method options from a generated service client.
 */
export function readMethodOptions(service, methodName, extensionName, extensionType) {
    let info = service.methods.find((m, i) => m.localName === methodName || i === methodName);
    return info && info.options && info.options[extensionName]
        ? extensionType.fromJson(info.options[extensionName])
        : undefined;
}
//# sourceMappingURL=reflection-info.js.map